@@ -28,8 +28,8 @@
 #include "daemon.h"
 #include "offline.h"
 
-Q_DECLARE_LOGGING_CATEGORY(PACKAGEKITQT_TRANSACTION)
 Q_DECLARE_LOGGING_CATEGORY(PACKAGEKITQT_DAEMON)
+Q_DECLARE_LOGGING_CATEGORY(PACKAGEKITQT_OFFLINE)
 
 class OrgFreedesktopPackageKitInterface;
 
